@@ -92,7 +92,10 @@ class Server(object):
                                 pool_instance=pool_instance,
                                 filters=filters)
         self._uuids = []
-
+        
+    def close(self):
+        self.res.close()
+        
     def info(self, _raw_json=False):
         """ info of server
         @param _raw_json: return raw json instead deserializing it
@@ -142,28 +145,29 @@ class Server(object):
         del self[dbname]
 
     #TODO: maintain list of replications
-    def replicate(self, source, target, doc_ids=None, 
-            continuous=False, create_target=False):
+    def replicate(self, source, target, **params):
         """
         simple handler for replication
 
         @param source: str, URI or dbname of the source
         @param target: str, URI or dbname of the target
-        @param doc_ids: list, default is None, replicate only these ids.
-        @param continuous: boolean, default is False, set the type of replication
-        @param create_target: boolean, default is False, create the target db
+        @param params: replication options
         
         More info about replication here :
         http://wiki.apache.org/couchdb/Replication
 
         """
-        resp = self.res.post('/_replicate', payload={
+        payload = {
             "source": source,
             "target": target,
-            "doc_ids": doc_ids,
-            "continuous": continuous,
-            "create_target": create_target
-        })
+        }
+        payload.update(params)
+        resp = self.res.post('/_replicate', payload=payload)
+        return resp.json_body
+        
+    def active_tasks(self):
+        """ return active tasks """
+        resp = self.res.get('/_active_tasks')
         return resp.json_body
 
     def uuids(self, count=1, raw=False):
@@ -184,20 +188,6 @@ class Server(object):
             self._uuids = self.uuids(count=self._uuid_batch_count)["uuids"]
         return self._uuids.pop()
 
-    def add_authorization(self, obj_auth):
-        """
-        Allow you to add basic authentication or any authentication
-        object inherited from `restkit`.
-
-        ex:
-
-            >>> from couchdbkit import Server
-            >>> from restkit import BasicAuth
-            >>> server = Server()
-            >>> server.add_authorization(BasicAuth(username, password))
-        """
-        self.res.add_filter(obj_auth)
-
     def __getitem__(self, dbname):
         return Database(self._db_uri(dbname), server=self)
 
@@ -224,6 +214,8 @@ class Server(object):
     def _db_uri(self, dbname):
         if dbname.startswith("/"):
             dbname = dbname[1:]
+            
+        dbname = url_quote(dbname, safe=":")
         return "/".join([self.uri, dbname])
 
 class Database(object):
@@ -241,13 +233,12 @@ class Database(object):
         @param server: Server instance
 
         """
-        uri_parsed = urlparse.urlparse(uri)
-        self.server_uri = "%s://%s" % (uri_parsed.scheme, uri_parsed.netloc)
-        self.dbname = uri_parsed.path.strip("/")
+        self.uri = uri
+        self.server_uri, self.dbname = uri.rsplit("/", 1)
 
         if server is not None:
             if not hasattr(server, 'next_uuid'):
-                raise TypeError('%s is not a couchdbkit.server instance' %
+                raise TypeError('%s is not a couchdbkit.Server instance' %
                             server.__class__.__name__)
             self.server = server
         else:
@@ -255,18 +246,15 @@ class Database(object):
                                     pool_instance=pool_instance,
                                     filters=filters)
 
-        try:
-            self.server.res.head('/%s/' % url_quote(self.dbname, safe=":"))
-        except resource.ResourceNotFound:
-            if create:
-                self.server.res.put('/%s/' % url_quote(self.dbname, safe=":"))
-            else:
-                raise
+        if create:
+            try:
+                self.server.res.head('/%s/' % self.dbname)
+            except resource.ResourceNotFound:
+                self.server.res.put('/%s/' % self.dbname)
+
 
         self.res = server.res.clone()
-        if "/" in self.dbname:
-            self.res.safe = ":/%"
-        self.res.update_uri('/%s' % url_quote(self.dbname, safe=":"))
+        self.res.uri =  "/".join([self.res.uri, self.dbname])
 
     def __repr__(self):
         return "<%s %s>" % (self.__class__.__name__, self.dbname)
@@ -276,6 +264,9 @@ class Database(object):
         """ Create a database from its url. """
         warnings.warn("from_uri is deprecated", DeprecationWarning)
         return cls(uri)
+        
+    def close(self):
+        self.res.close()
 
     def info(self, _raw_json=False):
         """
